# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.7](https://github.com/conda/rattler/compare/path_resolver-v0.2.6...path_resolver-v0.2.7) - 2026-03-18

### Other

- update Cargo.toml dependencies

## [0.2.6](https://github.com/conda/rattler/compare/path_resolver-v0.2.5...path_resolver-v0.2.6) - 2026-03-16

### Other

- Improve path_resolver robustness with expanded test suite ([#2192](https://github.com/conda/rattler/pull/2192))

## [0.2.5](https://github.com/conda/rattler/compare/path_resolver-v0.2.4...path_resolver-v0.2.5) - 2026-02-19

### Other

- Typo and clippy fixes ([#2047](https://github.com/conda/rattler/pull/2047))

## [0.2.4](https://github.com/conda/rattler/compare/path_resolver-v0.2.3...path_resolver-v0.2.4) - 2025-12-18

### Other

- update README.md with new banner image ([#1926](https://github.com/conda/rattler/pull/1926))

## [0.2.3](https://github.com/conda/rattler/compare/path_resolver-v0.2.2...path_resolver-v0.2.3) - 2025-12-08

### Other

- update Cargo.toml dependencies

## [0.2.2](https://github.com/conda/rattler/compare/path_resolver-v0.2.1...path_resolver-v0.2.2) - 2025-10-28

### Other

- Replace fxhash with ahash ([#1674](https://github.com/conda/rattler/pull/1674))

## [0.2.1](https://github.com/conda/rattler/compare/path_resolver-v0.2.0...path_resolver-v0.2.1) - 2025-09-30

### Fixed

- Rattler not copying back symbolic links from the clobbers directory. ([#1685](https://github.com/conda/rattler/pull/1685))

## [0.2.0](https://github.com/conda/rattler/compare/path_resolver-v0.1.2...path_resolver-v0.2.0) - 2025-08-22

### Other

- optimize path resolver ([#1611](https://github.com/conda/rattler/pull/1611))

## [0.1.2](https://github.com/conda/rattler/compare/path_resolver-v0.1.1...path_resolver-v0.1.2) - 2025-07-23

### Other

- update Cargo.toml dependencies

## [0.1.1](https://github.com/conda/rattler/compare/path_resolver-v0.1.0...path_resolver-v0.1.1) - 2025-07-14

### Other

- release ([#1512](https://github.com/conda/rattler/pull/1512))

## [0.1.0](https://github.com/conda/rattler/releases/tag/path_resolver-v0.1.0) - 2025-07-14

### Added

- *(clobber registry)* directory and file clobbering ([#1497](https://github.com/conda/rattler/pull/1497))
